@@ -4,37 +4,37 @@ def marcaComoPaga(self, state_change, **kw):
     obj = state_change.object
     obj.setPaga(True)
     obj.reindexObject()
-    template = obj.template_pagamento_realizado(obj)
+    template = obj.template_pagamento_realizado
     params = {
         'nome': obj.getNome(),
         'email': obj.getEmail(),
         'URL': obj.absolute_url(),
     }
-    obj.MailHost.send(template % params)
+    _enviaEmail(obj, template(obj), template.title, params)
 
 def enviaEmailConfirmacao(self, state_change, **kw):
     obj = state_change.object
-    template = obj.template_inscricao(obj)
+    template = obj.template_inscricao
     params = {
         'nome': obj.getNome(),
         'email': obj.getEmail(),
         'URL': obj.absolute_url(),
     }
-    obj.MailHost.send(template % params)
+    _enviaEmail(obj, template(obj), template.title, params)
 
 def depoisSalvar(self, state_change, **kw):
     obj = state_change.object
-    template = obj.template_recebimento_trabalho(obj)
+    template = obj.template_recebimento_trabalho
     params = {
         'nome': obj.getNome(),
         'email': obj.getEmail(),
         'titulo': obj.Title(),
     }
-    obj.MailHost.send(template % params)
+    _enviaEmail(obj, template(obj), template.title, params)
 
 def enviaEmailPreInscritos(self, state_change, **kw):
     obj = state_change.object
-    template = obj.template_confirmacao(obj)
+    template = obj.template_confirmacao
     inscricoes = obj.portal_catalog(portal_type='Inscricao',
                                     review_state='pre-inscrito')
     for inscricao in inscricoes:
@@ -43,5 +43,10 @@ def enviaEmailPreInscritos(self, state_change, **kw):
             'email': inscricao.getEmail,
             'UID': inscricao.UID,
         }
-        obj.MailHost.send(template % params)
+        _enviaEmail(obj, template(obj), template.title, params)
 
+def _enviaEmail(obj, template, subject, params, charset='utf-8'):
+    mto = "%s <%s>" % (params['nome'], params['email'])
+    mfrom = "%s <%s>" % (obj.email_from_name, obj.email_from_address)
+    obj.MailHost.secureSend(template % params, mto, mfrom,
+                            subject, charset=charset)
